@@ -67,7 +67,7 @@ def cache_to_django(
                 if 'django_id' in redis_instance.keys():
                     redis_instances_django_ids.append(redis_instance['django_id'])
 
-            all_django_instances = django_model.objects.all()
+            all_django_instances = await django_sync_to_async_list(django_model.objects.all())
             async_tasks = []
             completed = 0
             to_complete = len(all_django_instances)
@@ -147,17 +147,20 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
         changed_fields_to_update = {}
         for redis_field_name, redis_field_value in django_params.items():
             django_instance_fields_value = getattr(django_instance, redis_field_name)
-            if django_instance_fields_value.__class__ == django_models.DateTimeField:
-                if django_instance_fields_value.isoformat() != redis_field_value.isoformat():
+            if django_instance_fields_value.__class__ == datetime.datetime:
+                if redis_field_value.__class__ == datetime.datetime:
+                    redis_field_value_formatted = redis_field_value.strftime('%Y.%m.%d-%H:%M:%S')
+                    django_instance_fields_value_formatted = django_instance_fields_value.strftime('%Y.%m.%d-%H:%M:%S')
+                    if redis_field_value_formatted != django_instance_fields_value_formatted:
+                        changed_fields_to_update[redis_field_name] = redis_field_value
+                else:
                     changed_fields_to_update[redis_field_name] = redis_field_value
             elif django_instance_fields_value != redis_field_value:
-                print(django_instance_fields_value, redis_field_value, type(django_instance_fields_value), type(redis_field_value))
                 changed_fields_to_update[redis_field_name] = redis_field_value
         changed_many_to_many_fields_to_update = {}
         for redis_field_name, redis_field_value in django_many_to_many_params.items():
             django_instance_fields_value = list(getattr(django_instance, redis_field_name).all())
             if django_instance_fields_value != redis_field_value:
-                print(django_instance_fields_value, redis_field_value, type(django_instance_fields_value), type(redis_field_value))
                 changed_many_to_many_fields_to_update[redis_field_name] = redis_field_value
         print(need_to_create, changed_fields_to_update, changed_many_to_many_fields_to_update)
     #     django_model.objects.filter(id=django_id).update(**changed_fields_to_update)
